OptionsStruct = struct;

OptionsStruct.NumberOfAtoms           = 5E7;
OptionsStruct.DipolarPolarAngle       = deg2rad(0);
OptionsStruct.DipolarAzimuthAngle     = 0;
OptionsStruct.ScatteringLength        = 102;

OptionsStruct.TrapFrequencies         = [50, 20, 150];
OptionsStruct.TrapPotentialType       = 'Harmonic';

OptionsStruct.NumberOfGridPoints      = [128, 256, 128];
OptionsStruct.Dimensions              = [40, 80, 40];
OptionsStruct.UseApproximationForLHY  = true;
OptionsStruct.IncludeDDICutOff        = true;
OptionsStruct.CutoffType              = 'Cylindrical';
OptionsStruct.SimulationMode          = 'ImaginaryTimeEvolution'; % 'ImaginaryTimeEvolution' | 'RealTimeEvolution' | 'EnergyMinimization'
OptionsStruct.GradientDescentMethod   = 'NonLinearCGD';           % 'HeavyBall' | 'NonLinearCGD' 
OptionsStruct.MaxIterationsForGD      = 15000;
OptionsStruct.TimeStepSize            = 1E-3;            % in s
OptionsStruct.MinimumTimeStepSize     = 1E-6;            % in s
OptionsStruct.TimeCutOff              = 1E4;             % in s
OptionsStruct.EnergyTolerance         = 5E-10;
OptionsStruct.ResidualTolerance       = 1E-05;
OptionsStruct.NoiseScaleFactor        = 0.010;

OptionsStruct.PlotLive                = true;
OptionsStruct.JobNumber               = 0;
OptionsStruct.RunOnGPU                = false;
OptionsStruct.SaveData                = true;
OptionsStruct.SaveDirectory           = './Results/Data_3D/ImagTimeProp';
options                               = Helper.convertstruct2cell(OptionsStruct);

sim                                   = Simulator.DipolarGas(options{:});
pot                                   = Simulator.Potentials(options{:});
sim.Potential                         = pot.trap();

%-% Run Simulation %-%
NumberOfOutputs                       = 5;
[Params, Transf, psi, V, VDk, stats]  = Helper.runWithProfiling(@() sim.run(), NumberOfOutputs, OptionsStruct.SaveDirectory);
fprintf('Runtime: %.3f seconds\n', stats.runtime);
fprintf('Memory used: %.2f MB\n', stats.workspaceMemoryMB);